@@ -1,8 +1,8 @@
 import builtins
+import collections
 import dataclasses
 import inspect
 import os
-import re
 import sys
 from array import array
 from collections import Counter, UserDict, UserList, defaultdict, deque
@@ -29,8 +29,7 @@ from pipenv.patched.notpip._vendor.rich.repr import RichReprResult
 try:
     import pipenv.vendor.attr as _attr_module
 except ImportError:  # pragma: no cover
-    _attr_module = None  # type: ignore
-
+    _attr_module = None  # type: ignore[assignment]
 
 from . import get_console
 from ._loop import loop_last
@@ -80,6 +79,29 @@ def _is_dataclass_repr(obj: object) -> bool:
         return False
 
 
+_dummy_namedtuple = collections.namedtuple("_dummy_namedtuple", [])
+
+
+def _has_default_namedtuple_repr(obj: object) -> bool:
+    """Check if an instance of namedtuple contains the default repr
+
+    Args:
+        obj (object): A namedtuple
+
+    Returns:
+        bool: True if the default repr is used, False if there's a custom repr.
+    """
+    obj_file = None
+    try:
+        obj_file = inspect.getfile(obj.__repr__)
+    except (OSError, TypeError):
+        # OSError handles case where object is defined in __main__ scope, e.g. REPL - no filename available.
+        # TypeError trapped defensively, in case of object without filename slips through.
+        pass
+    default_repr_file = inspect.getfile(_dummy_namedtuple.__repr__)
+    return obj_file == default_repr_file
+
+
 def _ipy_display_hook(
     value: Any,
     console: Optional["Console"] = None,
@@ -93,7 +115,7 @@ def _ipy_display_hook(
     from .console import ConsoleRenderable  # needed here to prevent circular import
 
     # always skip rich generated jupyter renderables or None values
-    if isinstance(value, JupyterRenderable) or value is None:
+    if _safe_isinstance(value, JupyterRenderable) or value is None:
         return
 
     console = console or get_console()
@@ -124,12 +146,12 @@ def _ipy_display_hook(
                     return  # Delegate rendering to IPython
 
     # certain renderables should start on a new line
-    if isinstance(value, ConsoleRenderable):
+    if _safe_isinstance(value, ConsoleRenderable):
         console.line()
 
     console.print(
         value
-        if isinstance(value, RichRenderable)
+        if _safe_isinstance(value, RichRenderable)
         else Pretty(
             value,
             overflow=overflow,
@@ -144,6 +166,16 @@ def _ipy_display_hook(
     )
 
 
+def _safe_isinstance(
+    obj: object, class_or_tuple: Union[type, Tuple[type, ...]]
+) -> bool:
+    """isinstance can fail in rare cases, for example types with no __class__"""
+    try:
+        return isinstance(obj, class_or_tuple)
+    except Exception:
+        return False
+
+
 def install(
     console: Optional["Console"] = None,
     overflow: "OverflowMethod" = "ignore",
@@ -175,10 +207,10 @@ def install(
         """Replacement sys.displayhook which prettifies objects with Rich."""
         if value is not None:
             assert console is not None
-            builtins._ = None  # type: ignore
+            builtins._ = None  # type: ignore[attr-defined]
             console.print(
                 value
-                if isinstance(value, RichRenderable)
+                if _safe_isinstance(value, RichRenderable)
                 else Pretty(
                     value,
                     overflow=overflow,
@@ -189,13 +221,13 @@ def install(
                 ),
                 crop=crop,
             )
-            builtins._ = value  # type: ignore
+            builtins._ = value  # type: ignore[attr-defined]
 
     try:  # pragma: no cover
-        ip = get_ipython()  # type: ignore
+        ip = get_ipython()  # type: ignore[name-defined]
         from IPython.core.formatters import BaseFormatter
 
-        class RichFormatter(BaseFormatter):  # type: ignore
+        class RichFormatter(BaseFormatter):  # type: ignore[misc]
             pprint: bool = True
 
             def __call__(self, value: Any) -> Any:
@@ -314,6 +346,7 @@ class Pretty(JupyterMixin):
             indent_size=self.indent_size,
             max_length=self.max_length,
             max_string=self.max_string,
+            expand_all=self.expand_all,
         )
         text_width = (
             max(cell_len(line) for line in pretty_str.splitlines()) if pretty_str else 0
@@ -355,7 +388,7 @@ _MAPPING_CONTAINERS = (dict, os._Environ, MappingProxyType, UserDict)
 def is_expandable(obj: Any) -> bool:
     """Check if an object may be expanded by pretty print."""
     return (
-        isinstance(obj, _CONTAINERS)
+        _safe_isinstance(obj, _CONTAINERS)
         or (is_dataclass(obj))
         or (hasattr(obj, "__rich_repr__"))
         or _is_attr_object(obj)
@@ -373,6 +406,7 @@ class Node:
     empty: str = ""
     last: bool = False
     is_tuple: bool = False
+    is_namedtuple: bool = False
     children: Optional[List["Node"]] = None
     key_separator = ": "
     separator: str = ", "
@@ -387,7 +421,7 @@ class Node:
         elif self.children is not None:
             if self.children:
                 yield self.open_brace
-                if self.is_tuple and len(self.children) == 1:
+                if self.is_tuple and not self.is_namedtuple and len(self.children) == 1:
                     yield from self.children[0].iter_tokens()
                     yield ","
                 else:
@@ -514,6 +548,25 @@ class _Line:
             )
 
 
+def _is_namedtuple(obj: Any) -> bool:
+    """Checks if an object is most likely a namedtuple. It is possible
+    to craft an object that passes this check and isn't a namedtuple, but
+    there is only a minuscule chance of this happening unintentionally.
+
+    Args:
+        obj (Any): The object to test
+
+    Returns:
+        bool: True if the object is a namedtuple. False otherwise.
+    """
+    try:
+        fields = getattr(obj, "_fields", None)
+    except Exception:
+        # Being very defensive - if we cannot get the attr then its not a namedtuple
+        return False
+    return isinstance(obj, tuple) and isinstance(fields, tuple)
+
+
 def traverse(
     _object: Any,
     max_length: Optional[int] = None,
@@ -539,7 +592,7 @@ def traverse(
         """Get repr string for an object, but catch errors."""
         if (
             max_string is not None
-            and isinstance(obj, (bytes, str))
+            and _safe_isinstance(obj, (bytes, str))
             and len(obj) > max_string
         ):
             truncated = len(obj) - max_string
@@ -565,7 +618,7 @@ def traverse(
 
         def iter_rich_args(rich_args: Any) -> Iterable[Union[Any, Tuple[str, Any]]]:
             for arg in rich_args:
-                if isinstance(arg, tuple):
+                if _safe_isinstance(arg, tuple):
                     if len(arg) == 3:
                         key, child, default = arg
                         if default == child:
@@ -622,7 +675,7 @@ def traverse(
                             last=root,
                         )
                     for last, arg in loop_last(args):
-                        if isinstance(arg, tuple):
+                        if _safe_isinstance(arg, tuple):
                             key, child = arg
                             child_node = _traverse(child, depth=depth + 1)
                             child_node.last = last
@@ -689,7 +742,7 @@ def traverse(
 
         elif (
             is_dataclass(obj)
-            and not isinstance(obj, type)
+            and not _safe_isinstance(obj, type)
             and not fake_attributes
             and (_is_dataclass_repr(obj) or py_version == (3, 6))
         ):
@@ -721,10 +774,28 @@ def traverse(
                     append(child_node)
 
                 pop_visited(obj_id)
-
-        elif isinstance(obj, _CONTAINERS):
+        elif _is_namedtuple(obj) and _has_default_namedtuple_repr(obj):
+            if reached_max_depth:
+                node = Node(value_repr="...")
+            else:
+                children = []
+                class_name = obj.__class__.__name__
+                node = Node(
+                    open_brace=f"{class_name}(",
+                    close_brace=")",
+                    children=children,
+                    empty=f"{class_name}()",
+                )
+                append = children.append
+                for last, (key, value) in loop_last(obj._asdict().items()):
+                    child_node = _traverse(value, depth=depth + 1)
+                    child_node.key_repr = key
+                    child_node.last = last
+                    child_node.key_separator = "="
+                    append(child_node)
+        elif _safe_isinstance(obj, _CONTAINERS):
             for container_type in _CONTAINERS:
-                if isinstance(obj, container_type):
+                if _safe_isinstance(obj, container_type):
                     obj_type = container_type
                     break
 
@@ -752,7 +823,7 @@ def traverse(
                 num_items = len(obj)
                 last_item_index = num_items - 1
 
-                if isinstance(obj, _MAPPING_CONTAINERS):
+                if _safe_isinstance(obj, _MAPPING_CONTAINERS):
                     iter_items = iter(obj.items())
                     if max_length is not None:
                         iter_items = islice(iter_items, max_length)
@@ -770,14 +841,15 @@ def traverse(
                         child_node.last = index == last_item_index
                         append(child_node)
                 if max_length is not None and num_items > max_length:
-                    append(Node(value_repr=f"... +{num_items-max_length}", last=True))
+                    append(Node(value_repr=f"... +{num_items - max_length}", last=True))
             else:
                 node = Node(empty=empty, children=[], last=root)
 
             pop_visited(obj_id)
         else:
             node = Node(value_repr=to_repr(obj), last=root)
-        node.is_tuple = isinstance(obj, tuple)
+        node.is_tuple = _safe_isinstance(obj, tuple)
+        node.is_namedtuple = _is_namedtuple(obj)
         return node
 
     node = _traverse(_object, root=True)
@@ -812,13 +884,13 @@ def pretty_repr(
         str: A possibly multi-line representation of the object.
     """
 
-    if isinstance(_object, Node):
+    if _safe_isinstance(_object, Node):
         node = _object
     else:
         node = traverse(
             _object, max_length=max_length, max_string=max_string, max_depth=max_depth
         )
-    repr_str = node.render(
+    repr_str: str = node.render(
         max_width=max_width, indent_size=indent_size, expand_all=expand_all
     )
     return repr_str
@@ -868,6 +940,15 @@ if __name__ == "__main__":  # pragma: no cover
             1 / 0
             return "this will fail"
 
+    from typing import NamedTuple
+
+    class StockKeepingUnit(NamedTuple):
+        name: str
+        description: str
+        price: float
+        category: str
+        reviews: List[str]
+
     d = defaultdict(int)
     d["foo"] = 5
     data = {
@@ -894,9 +975,16 @@ if __name__ == "__main__":  # pragma: no cover
             ]
         ),
         "atomic": (False, True, None),
+        "namedtuple": StockKeepingUnit(
+            "Sparkling British Spring Water",
+            "Carbonated spring water",
+            0.9,
+            "water",
+            ["its amazing!", "its terrible!"],
+        ),
         "Broken": BrokenRepr(),
     }
-    data["foo"].append(data)  # type: ignore
+    data["foo"].append(data)  # type: ignore[attr-defined]
 
     from pipenv.patched.notpip._vendor.rich import print
 
