@@ -8,11 +8,10 @@ import sys
 import warnings
 from functools import lru_cache
 
-import crayons
-from click import echo as click_echo
-
 from pipenv import environments
 from pipenv.exceptions import RequirementError, ResolutionFailure
+from pipenv.utils.constants import MYPY_RUNNING
+from pipenv.vendor import click
 from pipenv.vendor.requirementslib import Pipfile, Requirement
 from pipenv.vendor.requirementslib.models.utils import DIRECT_URL_RE
 from pipenv.vendor.vistir import TemporaryDirectory, open_file
@@ -33,11 +32,10 @@ from .locking import format_requirement_for_lockfile, prepare_lockfile
 from .shell import make_posix, subprocess_run, temp_environ
 from .spinner import create_spinner
 
-if environments.MYPY_RUNNING:
+if MYPY_RUNNING:
     from typing import Any, Dict, List, Optional, Set, Tuple, Union  # noqa
 
     from pipenv.project import Project  # noqa
-    from pipenv.vendor.requirementslib import Pipfile, Requirement  # noqa
     from pipenv.vendor.requirementslib.models.requirements import Line  # noqa
 
 
@@ -367,13 +365,13 @@ class Resolver:
                     new_req = new_req.add_hashes(hashes)
                     name, entry = new_req.pipfile_entry
                     locked_deps[pep423_name(name)] = translate_markers(entry)
-                    click_echo(
+                    click.echo(
                         "{} doesn't match your environment, "
                         "its dependencies won't be resolved.".format(req.as_line()),
                         err=True,
                     )
                 else:
-                    click_echo(
+                    click.echo(
                         "Could not find a version of {} that matches your environment, "
                         "it will be skipped.".format(req.as_line()),
                         err=True,
@@ -632,11 +630,11 @@ class Resolver:
     def get_resolver(self, clear=False):
         from pipenv.vendor.pip_shims.shims import (
             WheelCache,
-            get_requirement_tracker,
+            get_build_tracker,
             global_tempdir_manager,
         )
 
-        with global_tempdir_manager(), get_requirement_tracker() as req_tracker, TemporaryDirectory(
+        with global_tempdir_manager(), get_build_tracker() as build_tracker, TemporaryDirectory(
             suffix="-build", prefix="pipenv-"
         ) as directory:
             pip_options = self.pip_options
@@ -646,7 +644,7 @@ class Resolver:
             preparer = self.pip_command.make_requirement_preparer(
                 temp_build_dir=directory,
                 options=pip_options,
-                req_tracker=req_tracker,
+                build_tracker=build_tracker,
                 session=self.session,
                 finder=finder,
                 use_user_site=False,
@@ -737,9 +735,9 @@ class Resolver:
             return self.prepend_hash_types(collected_hashes, shims.FAVORITE_HASH)
         except (ValueError, KeyError, ConnectionError):
             if self.project.s.is_verbose():
-                click_echo(
+                click.echo(
                     "{}: Error generating hash for {}".format(
-                        crayons.red("Warning", bold=True), ireq.name
+                        click.style("Warning", bold=True, fg="Red"), ireq.name
                     ),
                     err=True,
                 )
@@ -1026,19 +1024,19 @@ def venv_resolve_deps(
             if c.returncode == 0:
                 sp.green.ok(environments.PIPENV_SPINNER_OK_TEXT.format("Success!"))
                 if not project.s.is_verbose() and c.stderr.strip():
-                    click_echo(crayons.yellow(f"Warning: {c.stderr.strip()}"), err=True)
+                    click.echo(click.style(f"Warning: {c.stderr.strip()}"), err=True)
             else:
                 sp.red.fail(
                     environments.PIPENV_SPINNER_FAIL_TEXT.format("Locking Failed!")
                 )
-                click_echo(f"Output: {c.stdout.strip()}", err=True)
-                click_echo(f"Error: {c.stderr.strip()}", err=True)
+                click.echo(f"Output: {c.stdout.strip()}", err=True)
+                click.echo(f"Error: {c.stderr.strip()}", err=True)
     try:
         with open(target_file.name) as fh:
             results = json.load(fh)
     except (IndexError, json.JSONDecodeError):
-        click_echo(c.stdout.strip(), err=True)
-        click_echo(c.stderr.strip(), err=True)
+        click.echo(c.stdout.strip(), err=True)
+        click.echo(c.stderr.strip(), err=True)
         if os.path.exists(target_file.name):
             os.unlink(target_file.name)
         raise RuntimeError("There was a problem with locking.")
